import { Router } from '@angular/router';
import { Observable } from 'rxjs';
import { ApplicationApiService } from './api/application-api.service';
import { AuthService } from './auth.service';
import { GlobalEventService } from './global-event.service';
import { Application, ApplicationInfo } from './models/application/application.interface';
import { Category } from './models/application/category.interface';
import { Tenant } from './models/customer/tenant.interface';
import { ApplicationAnalytics } from './models/user/application-analytics.interface';
import { TenantSelectionService } from './tenant-selection.service';
export declare class ApplicationService {
    private applicationApi;
    private authService;
    private tenantService;
    private globalEventService;
    /**
     * Applications list of the authenticated user.
     */
    set applications(apps: Application[]);
    get applications(): Application[];
    _applications: Application[];
    get applicationsAnalytics(): ApplicationAnalytics[];
    set applicationsAnalytics(apps: ApplicationAnalytics[]);
    _applicationsAnalytics: ApplicationAnalytics[];
    private analyticsUpdated$;
    /**
     * Map that will contain applications grouped by categories
     */
    private appMap;
    set categories(categories: Category[]);
    get categories(): Category[];
    _categories: Category[];
    private appMap$;
    constructor(applicationApi: ApplicationApiService, authService: AuthService, tenantService: TenantSelectionService, globalEventService: GlobalEventService);
    /**
     * Get Applications list for an user and save it in a property.
     */
    list(): Observable<ApplicationInfo>;
    /**
     * Get Applications list grouped by categories in a hashMap.
     */
    getAppsMap(): Observable<Map<Category, Application[]>>;
    /**
     * Get Applications list grouped by categories in a hashMap of the active tenant.
     */
    getActiveTenantAppsMap(): Observable<Map<Category, Application[]>>;
    /**
     * Returns the provided tenant application map as Map<Category, Application[]>
     * @param tenant - tenant whitch we want applications
     */
    getTenantAppMap(tenant: Tenant): Map<Category, Application[]>;
    openApplication(app: Application, router: Router, uiUrl: string, tenantIdentifier?: number): void;
    getApplicationUrl(app: Application, tenantIdentifier?: number): string;
    getApplicationTenants(appId: any): Tenant[];
    private sortMapByCategory;
    getAppById(identifier: string): Application;
    /**
     * Return an observable that notify if the current application has a tenant list or not.
     */
    hasTenantList(): Observable<boolean>;
    /**
     * Convert a map using a string category identifier as key to a map using a Category object instead
     * @param stringMap - the map to convert as Map<string, Application[]>
     */
    private convertToCategoryMap;
    private fillCategoriesWithApps;
    private getLastUsedApps;
    private getSortedAppsOfCategory;
    private sortApplications;
    private sortCategories;
    isApplicationExternalIdentifierEnabled(id: string): Observable<boolean>;
}
